* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix?version=CLOUD&locale=en-US&state=PRODUCTION)
  * …
  * [Custom Reports](https://help.sap.com/docs/leanix/ea/custom-reports?locale=en-US&state=PRODUCTION&version=CLOUD)
  * Using GraphQL Queries with Custom Reports
